==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/ScatterSplineSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { ScatterBaseDescription } from "./ScatterBaseDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var ScatterSplineSeriesDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ScatterSplineSeriesDescription, _super);
    function ScatterSplineSeriesDescription() {
        var _this = _super.call(this) || this;
        _this.ez = 0;
        return _this;
    }
    ScatterSplineSeriesDescription.prototype.get_type = function () {
        return "ScatterSplineSeries";
    };
    Object.defineProperty(ScatterSplineSeriesDescription.prototype, "stiffness", {
        get: function () {
            return this.ez;
        },
        set: function (a) {
            this.ez = a;
            this.e("Stiffness");
        },
        enumerable: true,
        configurable: true
    });
    ScatterSplineSeriesDescription.$t = markType(ScatterSplineSeriesDescription, 'ScatterSplineSeriesDescription', ScatterBaseDescription.$);
    return ScatterSplineSeriesDescription;
}(ScatterBaseDescription));
export { ScatterSplineSeriesDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/ScatterSplineSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ScatterBaseDescription } from "./ScatterBaseDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var ScatterSplineSeriesDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterSplineSeriesDescription, _super);
    function ScatterSplineSeriesDescription() {
        var _this = _super.call(this) || this;
        _this.g7 = 0;
        return _this;
    }
    ScatterSplineSeriesDescription.prototype.get_type = function () {
        return "ScatterSplineSeries";
    };
    Object.defineProperty(ScatterSplineSeriesDescription.prototype, "stiffness", {
        get: function () {
            return this.g7;
        },
        set: function (a) {
            this.g7 = a;
            this.g("Stiffness");
        },
        enumerable: false,
        configurable: true
    });
    ScatterSplineSeriesDescription.$t = markType(ScatterSplineSeriesDescription, 'ScatterSplineSeriesDescription', ScatterBaseDescription.$);
    return ScatterSplineSeriesDescription;
}(ScatterBaseDescription));
export { ScatterSplineSeriesDescription };
